# API Documentation

Welcome to the API documentation for rxiv-maker.

## Core Modules

- [__version__.py](__version__.py.md)
- [core.cache.cache_utils.py](core_cache_cache_utils.py.md)
- [core.error_codes.py](core_error_codes.py.md)
- [core.logging_config.py](core_logging_config.py.md)
- [engines.operations.validate.py](engines_operations_validate.py.md)
- [manuscript_utils.figure_utils.py](manuscript_utils_figure_utils.py.md)
- [utils.bibliography_parser.py](utils_bibliography_parser.py.md)
- [utils.citation_utils.py](utils_citation_utils.py.md)
- [utils.email_encoder.py](utils_email_encoder.py.md)
- [utils.github.py](utils_github.py.md)
- [utils.homebrew_checker.py](utils_homebrew_checker.py.md)
- [utils.install_detector.py](utils_install_detector.py.md)
- [utils.operation_ids.py](utils_operation_ids.py.md)
- [utils.platform.py](utils_platform.py.md)
- [utils.python_execution_reporter.py](utils_python_execution_reporter.py.md)
- [utils.text_utils.py](utils_text_utils.py.md)
- [utils.unicode_safe.py](utils_unicode_safe.py.md)
- [utils.url_to_doi.py](utils_url_to_doi.py.md)
- [validate.py](validate.py.md)

